==> gns3-0.6.1.tgz: lib/python2.5/site-packages/GNS3/Langs/DynamicStrings.py <==
# -*- coding: utf-8 -*-
# vim: expandtab ts=4 sw=4 sts=4:
#
# Copyright (C) 2007-2008 GNS3 Dev Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation;
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# Contact: developers@gns3.net
#

# This file is for pylupdate4, to allow us to translate strings that we 
# use dynamically in GNS3 with Qtlinguist

# Translation of the current language name
translate("MainWindow", "English")

# Preferences Dialog / Configurations Pages
translate('PreferencesDialog', 'General')
translate('PreferencesDialog', 'Applications')

# Nodes `symbols' names
translate('nodesDock', 'Router c1700')
translate('nodesDock', 'Router c2600')
translate('nodesDock', 'Router c2691')
translate('nodesDock', 'Router c3600')
translate('nodesDock', 'Router c3700')
translate('nodesDock', 'Router c7200')
translate('nodesDock', 'PIX firewall')
translate('nodesDock', 'Ethernet switch')
translate('nodesDock', 'Hub')
translate('nodesDock', 'ATM bridge')
translate('nodesDock', 'ATM switch')
translate('nodesDock', 'Frame Relay switch')
translate('nodesDock', 'Cloud')
translate('nodesDock', 'Decorative node')

==> gns3-0.7.2.tgz: lib/python2.6/site-packages/GNS3/Langs/DynamicStrings.py <==
# -*- coding: utf-8 -*-
# vim: expandtab ts=4 sw=4 sts=4:
#
# Copyright (C) 2007-2010 GNS3 Development Team (http://www.gns3.net/team).
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation;
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# developers@gns3.net
#

# This file is for pylupdate4, to allow us to translate strings that we 
# use dynamically in GNS3 with Qtlinguist

# Translation of the current language name
translate("MainWindow", "English")

# Preferences Dialog / Configurations Pages
translate('PreferencesDialog', 'General')
translate('PreferencesDialog', 'Applications')

# Nodes `symbols' names
translate('nodesDock', 'Router c1700')
translate('nodesDock', 'Router c2600')
translate('nodesDock', 'Router c2691')
translate('nodesDock', 'Router c3600')
translate('nodesDock', 'Router c3700')
translate('nodesDock', 'Router c7200')
translate('nodesDock', 'PIX firewall')
translate('nodesDock', 'Ethernet switch')
translate('nodesDock', 'ATM bridge')
translate('nodesDock', 'ATM switch')
translate('nodesDock', 'Frame Relay switch')
translate('nodesDock', 'Cloud')
translate('nodesDock', 'Decorative node')
translate('nodesDock', 'Juniper router')
translate('nodesDock', 'ASA firewall')
translate('nodesDock', 'IDS')
translate('nodesDock', 'Qemu host')
